@@ -16,22 +16,21 @@
 #include "k3bmovixdoc.h"
 #include "k3bmovixprogram.h"
 #include "k3bmovixfileitem.h"
-
 #include "k3bcore.h"
 #include "k3bdiritem.h"
 #include "k3bfileitem.h"
 #include "k3bbootitem.h"
 #include "k3bexternalbinmanager.h"
 #include "k3bisoimager.h"
+#include "k3b_i18n.h"
 
-#include <KLocale>
-#include <KDebug>
-#include <KTemporaryFile>
-#include <kio/global.h>
+#include <KIOCore/KIO/Global>
 
-#include <QTextStream>
-#include <QDir>
-#include <QStack>
+#include <QtCore/QDebug>
+#include <QtCore/QDir>
+#include <QtCore/QStack>
+#include <QtCore/QTemporaryFile>
+#include <QtCore/QTextStream>
 
 
 class K3b::MovixDocPreparer::Private
@@ -52,9 +51,9 @@ public:
     K3b::MovixDoc* doc;
     const K3b::MovixBin* eMovixBin;
 
-    KTemporaryFile* playlistFile;
-    KTemporaryFile* isolinuxConfigFile;
-    KTemporaryFile* movixRcFile;
+    QTemporaryFile* playlistFile;
+    QTemporaryFile* isolinuxConfigFile;
+    QTemporaryFile* movixRcFile;
 
     K3b::DirItem* isolinuxDir;
     K3b::DirItem* movixDir;
@@ -90,7 +89,7 @@ K3b::MovixDoc* K3b::MovixDocPreparer::doc() const
 
 void K3b::MovixDocPreparer::start()
 {
-    kDebug() << k_funcinfo;
+    qDebug();
     jobStarted();
 
     bool success = true;
@@ -111,7 +110,7 @@ void K3b::MovixDocPreparer::cancel()
 
 bool K3b::MovixDocPreparer::createMovixStructures()
 {
-    kDebug() << k_funcinfo;
+    qDebug();
     removeMovixStructures();
 
     if( doc() ) {
@@ -122,7 +121,7 @@ bool K3b::MovixDocPreparer::createMovixStructures()
     d->eMovixBin = dynamic_cast<const K3b::MovixBin*>( k3bcore->externalBinManager()->binObject("eMovix") );
     if( d->eMovixBin ) {
         bool success = false;
-        if( d->eMovixBin->version >= K3b::Version( 0, 9, 0 ) )
+        if( d->eMovixBin->version() >= K3b::Version( 0, 9, 0 ) )
             success = addMovixFilesNew();
         else
             success = addMovixFiles();
@@ -139,7 +138,7 @@ bool K3b::MovixDocPreparer::createMovixStructures()
 
 void K3b::MovixDocPreparer::removeMovixStructures()
 {
-    kDebug() << k_funcinfo;
+    qDebug();
     // remove movix files from doc
     // the dataitems do the cleanup in the doc
     delete d->movixDir;
@@ -172,7 +171,7 @@ void K3b::MovixDocPreparer::removeMovixStructures()
 bool K3b::MovixDocPreparer::writePlaylistFile()
 {
     delete d->playlistFile;
-    d->playlistFile = new KTemporaryFile();
+    d->playlistFile = new QTemporaryFile();
     d->playlistFile->open();
 
     QTextStream s( d->playlistFile );
@@ -193,7 +192,7 @@ bool K3b::MovixDocPreparer::writePlaylistFile()
 bool K3b::MovixDocPreparer::writeIsolinuxConfigFile( const QString& originalPath )
 {
     delete d->isolinuxConfigFile;
-    d->isolinuxConfigFile = new KTemporaryFile();
+    d->isolinuxConfigFile = new QTemporaryFile();
     d->isolinuxConfigFile->open();
 
     QTextStream s( d->isolinuxConfigFile );
@@ -227,7 +226,7 @@ bool K3b::MovixDocPreparer::writeIsolinuxConfigFile( const QString& originalPath
 bool K3b::MovixDocPreparer::writeMovixRcFile()
 {
     delete d->movixRcFile;
-    d->movixRcFile = new KTemporaryFile();
+    d->movixRcFile = new QTemporaryFile();
     d->movixRcFile->open();
 
     QTextStream s( d->movixRcFile );
@@ -256,15 +255,19 @@ bool K3b::MovixDocPreparer::writeMovixRcFile()
 bool K3b::MovixDocPreparer::addMovixFiles()
 {
     // first of all we create the directories
-    d->isolinuxDir = new K3b::DirItem( "isolinux", d->doc, d->doc->root() );
-    d->movixDir = new K3b::DirItem( "movix", d->doc, d->doc->root() );
+    d->isolinuxDir = new K3b::DirItem( "isolinux" );
+    d->movixDir = new K3b::DirItem( "movix" );
+    if (d->doc == Q_NULLPTR)
+        return false;
+    d->doc->root()->addDataItem( d->isolinuxDir );
+    d->doc->root()->addDataItem( d->movixDir );
     K3b::DirItem* kernelDir = d->doc->addEmptyDir( "kernel", d->isolinuxDir );
 
     // add the linux kernel
-    (void)new K3b::FileItem( d->eMovixBin->path + "/isolinux/kernel/vmlinuz", d->doc, kernelDir );
+    kernelDir->addDataItem( new K3b::FileItem( d->eMovixBin->path() + "/isolinux/kernel/vmlinuz", *d->doc ) );
 
     // add the boot image
-    K3b::BootItem* bootItem = d->doc->createBootItem( d->eMovixBin->path + "/isolinux/isolinux.bin",
+    K3b::BootItem* bootItem = d->doc->createBootItem( d->eMovixBin->path() + "/isolinux/isolinux.bin",
                                                     d->isolinuxDir );
     bootItem->setImageType( K3b::BootItem::NONE );
     bootItem->setLoadSize( 4 );
@@ -287,15 +290,15 @@ bool K3b::MovixDocPreparer::addMovixFiles()
     isolinuxFiles.removeOne( "kernel/vmlinuz" );
     for( QStringList::const_iterator it = isolinuxFiles.constBegin();
          it != isolinuxFiles.constEnd(); ++it ) {
-        QString path = d->eMovixBin->path + "/isolinux/" + *it;
-        (void)new K3b::FileItem( path, d->doc, d->isolinuxDir );
+        QString path = d->eMovixBin->path() + "/isolinux/" + *it;
+        d->isolinuxDir->addDataItem( new K3b::FileItem( path, *d->doc ) );
     }
 
     const QStringList& movixFiles = d->eMovixBin->movixFiles();
     for( QStringList::const_iterator it = movixFiles.constBegin();
          it != movixFiles.constEnd(); ++it ) {
-        QString path = d->eMovixBin->path + "/movix/" + *it;
-        (void)new K3b::FileItem( path, d->doc, d->movixDir );
+        QString path = d->eMovixBin->path() + "/movix/" + *it;
+        d->movixDir->addDataItem( new K3b::FileItem( path, *d->doc ) );
     }
 
     // add doku files
@@ -305,47 +308,47 @@ bool K3b::MovixDocPreparer::addMovixFiles()
     for( QStringList::const_iterator it = helpFiles.constBegin();
          it != helpFiles.constEnd(); ++it ) {
         // some emovix installations include backup-files, no one's perfect ;)
-        if( !(*it).endsWith( "~" ) )
-            (void)new K3b::FileItem( path + "/" + *it, d->doc, d->isolinuxDir );
+        if( !(*it).endsWith( '~' ) )
+            d->isolinuxDir->addDataItem( new K3b::FileItem( path + '/' + *it, *d->doc ) );
     }
 
 
     // add subtitle font dir
     if( !d->doc->subtitleFontset().isEmpty() &&
         d->doc->subtitleFontset() != i18n("none") ) {
-        d->mplayerDir = new K3b::DirItem( "mplayer", d->doc, d->doc->root() );
+        d->mplayerDir = new K3b::DirItem( "mplayer" );
+        d->doc->root()->addDataItem( d->mplayerDir );
 
         QString fontPath = d->eMovixBin->subtitleFontDir( d->doc->subtitleFontset() );
         QFileInfo fontType( fontPath );
         if( fontType.isDir() ) {
-            K3b::DirItem* fontDir = new K3b::DirItem( "font", d->doc, d->mplayerDir );
+            K3b::DirItem* fontDir = new K3b::DirItem( "font" );
+            d->mplayerDir->addDataItem( fontDir );
             QDir dir( fontPath );
             QStringList fontFiles = dir.entryList( QDir::Files );
             for( QStringList::const_iterator it = fontFiles.constBegin();
                  it != fontFiles.constEnd(); ++it ) {
-                (void)new K3b::FileItem( fontPath + "/" + *it, d->doc, fontDir );
+                fontDir->addDataItem( new K3b::FileItem( fontPath + '/' + *it, *d->doc ) );
             }
         }
         else {
             // just a ttf file
             // needs to be named: subfont.ttf and needs to be placed in mplayer/
             // instead of mplayer/font
-            (void)new K3b::FileItem( fontPath,
-                                   d->doc,
-                                   d->mplayerDir,
-                                   "subfont.ttf" );
+            d->mplayerDir->addDataItem( new K3b::FileItem( fontPath, *d->doc, "subfont.ttf" ) );
         }
     }
 
 
     // add movix-config-file and boot-config file
     if( writeMovixRcFile() &&
-        writeIsolinuxConfigFile( d->eMovixBin->path + "/isolinux/isolinux.cfg" ) &&
+        writeIsolinuxConfigFile( d->eMovixBin->path() + "/isolinux/isolinux.cfg" ) &&
         writePlaylistFile() ) {
 
-        (void)new K3b::FileItem( d->movixRcFile->fileName(), d->doc, d->movixDir, "movixrc" );
-        (void)new K3b::FileItem( d->isolinuxConfigFile->fileName(), d->doc, d->isolinuxDir, "isolinux.cfg" );
-        d->playlistFileItem = new K3b::FileItem( d->playlistFile->fileName(), d->doc, d->doc->root(), "movix.list" );
+        d->movixDir->addDataItem( new K3b::FileItem( d->movixRcFile->fileName(), *d->doc, "movixrc" ) );
+        d->isolinuxDir->addDataItem( new K3b::FileItem( d->isolinuxConfigFile->fileName(), *d->doc, "isolinux.cfg" ) );
+        d->playlistFileItem = new K3b::FileItem( d->playlistFile->fileName(), *d->doc, "movix.list" );
+        d->doc->root()->addDataItem( d->playlistFileItem );
 
         return true;
     }
@@ -361,6 +364,8 @@ bool K3b::MovixDocPreparer::addMovixFilesNew()
     // 3. add movixrc and movix.list files
     // 4. set weights for isolinux files
 
+    if (d->doc == Q_NULLPTR)
+        return false;
     // FIXME: use the settings from the doc
     const QStringList files = d->eMovixBin->files( d->doc->keyboardLayout(),
                                              d->doc->subtitleFontset(),
@@ -433,7 +438,8 @@ K3b::FileItem* K3b::MovixDocPreparer::createItem( const QString& localPath, cons
     K3b::DirItem* dir = createDir( docPath );
 
     // create the file in dir
-    K3b::FileItem* item = new K3b::FileItem( localPath, d->doc, dir );
+    K3b::FileItem* item = new K3b::FileItem( localPath, *d->doc );
+    dir->addDataItem( item );
 
     // remember the item to remove it becasue the dir cannot be removed
     if( dir == d->doc->root() )
@@ -449,12 +455,14 @@ K3b::DirItem* K3b::MovixDocPreparer::createDir( const QString& docPath )
     K3b::DirItem* dir = d->doc->root();
     for( QStringList::ConstIterator it = docPathSections.constBegin(); it != docPathSections.constEnd(); ++it ) {
         K3b::DataItem* next = dir->find( *it );
-        if( !next )
-            dir = new K3b::DirItem( *it, d->doc, dir );
-        else if( next->isDir() )
+        if( !next ) {
+            DirItem* newDir = new K3b::DirItem( *it );
+            dir->addDataItem( newDir );
+            dir = newDir;
+        } else if( next->isDir() ) {
             dir = static_cast<K3b::DirItem*>( next );
-        else {
-            kError() << "(K3b::MovixDocPreparer) found non-dir item where a dir was needed." << endl;
+        } else {
+            qCritical() << "(K3b::MovixDocPreparer) found non-dir item where a dir was needed." << endl;
             return 0;
         }
     }
@@ -471,4 +479,4 @@ K3b::DirItem* K3b::MovixDocPreparer::createDir( const QString& docPath )
     return dir;
 }
 
-#include "k3bmovixdocpreparer.moc"
+
